#!/usr/bin/env node
import React from 'react';
import { createCommand } from 'commander';
import { render } from 'ink';
import { cosmiconfig } from 'cosmiconfig';
import path from 'node:path';
import PQueue from 'p-queue';
import { App } from './App.js';
import { Error } from './Error.js';
import { getRequest, deleteRequest } from './network.js';
import { listPipelines, filterPipelinesByDate, deletePipeline } from './gitlab.js';
import { loadConfig, mergeCliArgumentsWithConfig } from './config.js';
function exit() {
    process.exitCode = 1;
}
const program = createCommand('gitlab-pipeline-deleter');
program
    .storeOptionsAsProperties(false)
    .description('Deletes old GitLab pipelines')
    .arguments('[gitlab-url]')
    .arguments('[project-id]')
    .arguments('[access-token]')
    .option('-d --days <days>', 'older than days', '30')
    .option('--trace', 'show stack traces for errors when possible', false)
    .action(async (gitlabUrlArgument, projectIdArgument, accessTokenArgument, options) => {
    const cliArguments = {
        gitlabUrl: gitlabUrlArgument,
        projectId: projectIdArgument,
        accessToken: accessTokenArgument,
        days: typeof options.days === 'string' ? parseInt(options.days, 10) : 30,
        trace: options.trace === true,
    };
    const configPath = path.resolve(process.cwd(), 'glpd.config.js');
    const explorer = cosmiconfig('gitlab-pipeline-deleter');
    const loadedConfig = await loadConfig(configPath, explorer);
    const glpdArguments = loadedConfig.andThen((config) => {
        return mergeCliArgumentsWithConfig(cliArguments, config);
    });
    if (glpdArguments.isErr) {
        render(React.createElement(Error, { exit: exit }, "Missing or invalid arguments"));
        return;
    }
    const { gitlabUrl, projectIds, accessToken, days, trace } = glpdArguments.value;
    const startDate = new Date();
    const listPipelinesFunction = listPipelines({
        getRequest,
        gitlabUrl: gitlabUrl,
        accessToken: accessToken,
    });
    const deletePipelineFunction = deletePipeline({
        deleteRequest,
        gitlabUrl: gitlabUrl,
        accessToken: accessToken,
    });
    const deleteQueue = new PQueue({ autoStart: false, interval: 1000, intervalCap: 10 });
    render(React.createElement(App, { gitlabUrl: gitlabUrl, projectIds: projectIds, accessToken: accessToken, days: days, startDate: startDate, exit: exit, listPipelines: listPipelinesFunction, filterPipelinesByDate: filterPipelinesByDate, deletePipeline: deletePipelineFunction, deleteQueue: deleteQueue, showStackTraces: trace }));
});
function crash(error) {
    console.error(error);
    exit();
}
program.parseAsync(process.argv).catch(crash);
//# sourceMappingURL=bin.js.map